@@ -3,7 +3,7 @@ use warnings;
 
 package JIRA::Client;
 {
-  $JIRA::Client::VERSION = '0.34';
+  $JIRA::Client::VERSION = '0.35';
 }
 # ABSTRACT: An extended interface to JIRA's SOAP API.
 
@@ -660,9 +660,36 @@ sub attach_strings_to_issue {
 }
 
 
+sub filter_issues {
+    my ($self, $filter, $limit) = @_;
+
+    $filter =~ s/^\s*"?//;
+    $filter =~ s/"?\s*$//;
+
+    my $issues = do {
+	if ($filter =~ /^(?:[A-Z]+-\d+\s+)*[A-Z]+-\d+$/i) {
+	    # space separated key list
+	    [map {$self->getIssue(uc $_)} split / /, $filter];
+	} elsif ($filter =~ /^[\w-]+$/i) {
+	    # saved filter
+	    $self->getIssuesFromFilterWithLimit($filter, 0, $limit || 1000);
+	} else {
+	    # JQL filter
+	    $self->getIssuesFromJqlSearch($filter, $limit || 1000);
+	}
+    };
+
+    # Order the issues by project key and then by numeric value using
+    # a Schwartzian transform.
+    map  {$_->[2]}
+	sort {$a->[0] cmp $b->[0] or $a->[1] <=> $b->[1]}
+	    map  {my ($p, $n) = ($_->{key} =~ /([A-Z]+)-(\d+)/); [$p, $n, $_]} @$issues;
+}
+
+
 package RemoteFieldValue;
 {
-  $RemoteFieldValue::VERSION = '0.34';
+  $RemoteFieldValue::VERSION = '0.35';
 }
 
 sub new {
@@ -678,7 +705,7 @@ sub new {
 
 package RemoteCustomFieldValue;
 {
-  $RemoteCustomFieldValue::VERSION = '0.34';
+  $RemoteCustomFieldValue::VERSION = '0.35';
 }
 
 sub new {
@@ -691,7 +718,7 @@ sub new {
 
 package RemoteComponent;
 {
-  $RemoteComponent::VERSION = '0.34';
+  $RemoteComponent::VERSION = '0.35';
 }
 
 sub new {
@@ -704,7 +731,7 @@ sub new {
 
 package RemoteVersion;
 {
-  $RemoteVersion::VERSION = '0.34';
+  $RemoteVersion::VERSION = '0.35';
 }
 
 sub new {
@@ -955,7 +982,7 @@ JIRA::Client - An extended interface to JIRA's SOAP API.
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -996,6 +1023,54 @@ L<http://docs.atlassian.com/software/jira/docs/api/rpc-jira-plugin/latest/com/at
 Moreover, it implements some other methods to make it easier to do
 some common operations.
 
+=head2 API METHODS
+
+With the exception of the API C<login> and C<logout> methods, which
+aren't needed, all other methods are available through the
+JIRA::Client object interface. You must call them with the same name
+as documented in the specification but you should not pass the
+C<token> argument, because it is supplied transparently by the
+JIRA::Client object.
+
+All methods fail by throwing exceptions (croaking, actually). You may
+want to guard against this by invoking them within an eval block, like
+this:
+
+  my $issue = eval { $jira->getIssue('TST-123') };
+  die "Can't getIssue('TST-123'): $@" if $@;
+
+Some of the API methods require hard-to-build data structures as
+arguments. This module tries to make them easier to call by accepting
+simpler structures and implicitly constructing the more elaborated
+ones before making the actual SOAP call. Note that this is an option,
+i.e, you can either pass the elaborate structures by yourself or the
+simpler ones in the call.
+
+The items below are all the implemented implicit conversions. Wherever
+a parameter of the type specified first is required (as an rvalue, not
+as an lvalue) by an API method you can safely pass a value of the type
+specified second.
+
+=over 4
+
+=item A B<issue key> as a string can be specified by a B<RemoteIssue> object.
+
+=item A B<RemoteComment> object can be specified by a string.
+
+=item A B<filterId> as a string can be specified by a B<RemoteFilter> object.
+
+=item A B<RemoteFieldValue> object array can be specified by a hash mapping field names to values.
+
+=back
+
+=head2 EXTRA METHODS
+
+This module implements some extra methods to add useful functionality
+to the API. They are described below. Note that their names don't
+follow the CamelCase convention used by the native API methods but the
+more Perlish underscore_separated_words convention so that you can
+distinguish them and we can avoid future name clashes.
+
 =head1 METHODS
 
 =head2 B<new> JIRAURL, USER, PASSWD [, <SOAP::Lite arguments>]
@@ -1273,6 +1348,49 @@ file names and the values their contents.
 The method retuns the value returned by the
 B<addBase64EncodedAttachmentsToIssue> API method.
 
+=head2 B<filter_issues> FILTER [, LIMIT]
+
+This method returns a list of RemoteIssue objects from the specified
+FILTER, which is a string that is understood in one of these ways (in
+order):
+
+=over
+
+=item A space-separated list of issue keys
+
+To specify issues explicitly by their keys, which must match
+/[A-Z]+-\d+/i. The letters in the key are upcased before being passed
+to getIssue. For example:
+
+    KEY-123 chave-234 CLAVE-345
+
+=item The name of a saved filter
+
+If FILTER is a single word, it is passed to
+getIssuesFromFilterWithLimit as a filter name. For example:
+
+    sprint-backlok-filter
+
+=item A JQL expression
+
+As a last resort, FILTER is passed to getIssuesFromJqlSearch as a JQL
+expression. For example:
+
+    project = CDS AND fixVersion = sprint-5
+
+=back
+
+The optional LIMIT argument specified the maximum number of issues
+that can be returned. It has a default limit of 1000, but this can be
+overriden by the JIRA server configuration.
+
+This method is meant to be used as a flexible interface for human
+beings to request a list of issues. Be warned, however, that you are
+responsible to de-taint the FILTER argument before passing it to the
+method.
+
+The returned list of RemoteIssue objects is sorted by issue key.
+
 =head2 B<RemoteFieldValue-E<gt>new> ID, VALUES
 
 The RemoteFieldValue object represents the value of a field of an
@@ -1311,54 +1429,6 @@ A scalar or an array of scalars.
 
 =head2 B<RemoteVersion-E<gt>new> ID, NAME
 
-=head1 API METHODS
-
-With the exception of the API C<login> and C<logout> methods, which
-aren't needed, all other methods are available through the
-JIRA::Client object interface. You must call them with the same name
-as documented in the specification but you should not pass the
-C<token> argument, because it is supplied transparently by the
-JIRA::Client object.
-
-All methods fail by throwing exceptions (croaking, actually). You may
-want to guard against this by invoking them within an eval block, like
-this:
-
-  my $issue = eval { $jira->getIssue('TST-123') };
-  die "Can't getIssue('TST-123'): $@" if $@;
-
-Some of the API methods require hard-to-build data structures as
-arguments. This module tries to make them easier to call by accepting
-simpler structures and implicitly constructing the more elaborated
-ones before making the actual SOAP call. Note that this is an option,
-i.e, you can either pass the elaborate structures by yourself or the
-simpler ones in the call.
-
-The items below are all the implemented implicit conversions. Wherever
-a parameter of the type specified first is required (as an rvalue, not
-as an lvalue) by an API method you can safely pass a value of the type
-specified second.
-
-=over 4
-
-=item A B<issue key> as a string can be specified by a B<RemoteIssue> object.
-
-=item A B<RemoteComment> object can be specified by a string.
-
-=item A B<filterId> as a string can be specified by a B<RemoteFilter> object.
-
-=item A B<RemoteFieldValue> object array can be specified by a hash mapping field names to values.
-
-=back
-
-=head1 EXTRA METHODS
-
-This module implements some extra methods to add useful functionality
-to the API. They are described below. Note that their names don't
-follow the CamelCase convention used by the native API methods but the
-more Perlish underscore_separated_words convention so that you can
-distinguish them and we can avoid future name clashes.
-
 =head1 OTHER CONSTRUCTORS
 
 The JIRA SOAP API uses several types of objects (i.e., classes) for
@@ -1372,7 +1442,7 @@ distribution.
 
 =head1 AUTHOR
 
-Gustavo Chaves <gnustavo@cpan.org>
+Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
